# Copyright 2016 Yelp Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import json
from typing import Any


def load_json(input_data: bytes) -> Any:
    data_str = input_data.decode()

    return json.loads(data_str)


def dump_json(obj: Any) -> bytes:
    serialized = json.dumps(obj, sort_keys=True)

    return serialized.encode()
